@@ -6,11 +6,13 @@
 import logging
 import socket
 import random
+import time
+
 
 # Sends statistics to the stats daemon over UDP
 class Client(object):
 
-    def __init__(self, host='localhost', port=8125):
+    def __init__(self, host='localhost', port=8125, prefix=None):
         """
         Create a new Statsd client.
         * host: the host where statsd is listening, defaults to localhost
@@ -21,15 +23,34 @@ class Client(object):
         """
         self.host = host
         self.port = int(port)
+        self.addr = (socket.gethostbyname(self.host), self.port)
+        self.prefix = prefix
         self.log = logging.getLogger("pystatsd.client")
         self.udp_sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
 
+    def timing_since(self, stat, start, sample_rate=1):
+        """
+        Log timing information as the number of microseconds since the provided time float
+        >>> start = time.time()
+        >>> # do stuff
+        >>> statsd_client.timing_since('some.time', start)
+        """
+        self.timing(stat, int((time.time() - start) * 1000000), sample_rate)
+
     def timing(self, stat, time, sample_rate=1):
         """
         Log timing information for a single stat
         >>> statsd_client.timing('some.time',500)
         """
-        stats = {stat: "%d|ms" % time}
+        stats = {stat: "%f|ms" % time}
+        self.send(stats, sample_rate)
+
+    def gauge(self, stat, value, sample_rate=1):
+        """
+        Log gauge information for a single stat
+        >>> statsd_client.gauge('some.gauge',42)
+        """
+        stats = {stat: "%f|g" % value}
         self.send(stats, sample_rate)
 
     def increment(self, stats, sample_rate=1):
@@ -62,18 +83,18 @@ class Client(object):
         """
         Squirt the metrics over UDP
         """
-        addr = (self.host, self.port)
 
-        sampled_data = {}
+        if self.prefix:
+            data = dict((".".join((self.prefix, stat)), value) for stat, value in data.iteritems())
 
         if sample_rate < 1:
             if random.random() > sample_rate:
                 return
             sampled_data = dict((stat, "%s|@%s" % (value, sample_rate)) for stat, value in data.iteritems())
         else:
-            sampled_data=data
+            sampled_data = data
 
         try:
-            [self.udp_sock.sendto("%s:%s" % (stat, value), addr) for stat, value in sampled_data.iteritems()]
+            [self.udp_sock.sendto("%s:%s" % (stat, value), self.addr) for stat, value in sampled_data.iteritems()]
         except:
             self.log.exception("unexpected error")
